/*

This function performs Random Data input function. It writes the data into a
particular byte of a page.

Parameter to be passed: ByteNo, PageNo, BlockNo, data to be written

Returns: None

*/


#include "Extern_Declaration.h"

/***************************************************************************************/


void RandomDataInput(unsigned int RIbyte, unsigned int RIpage, unsigned int RIblock, unsigned char DataIn)
{
	
	// check if write buffer is empty or not:
	
	while(!(*pNFC_STAT & WB_EMPTY));
	
	*pNFC_CMD =  PageWriteCmd[0];
		 
	/*  
	
	Set up the address cycles depending on Page and Block number passed:
	
	Column: A0-A11
	Page: 	A12-A17
	Block: 	A18-A28
	
	
	1st Address Cycle: A0-A7
	2nd Address Cycle: A8-A11
	3rd Address Cycle: A12-A19
	4th Address Cycle: A20-A27
	5th Address Cycle: A28
	
	*/
	
	short temp_Page = RIpage;
	short save_CPpage = RIpage;
	short temp_Block = RIblock;
	
	//Column
	*pNFC_ADDR = 0;
	*pNFC_ADDR = 0;
	
	//Page
	
	temp_Page = RIblock & 3;		// Get bits A18 and A19 from Block address
	temp_Page = temp_Page << 6;		// Shift to append with Page Address
	
	RIpage = RIpage | temp_Page;
	
	// First 2 bits of Block and 6 bits of Page are sent
	*pNFC_ADDR = RIpage;	
	
	// check if write buffer is empty or not:
	
	while(!(*pNFC_STAT & WB_EMPTY));	
	
	// Next 8 bits of Block address. i.e till 1023. 
			
	RIblock = temp_Block;
	RIblock = RIblock & 0x3FC;	// Mask to get A20-A27	
	RIblock = RIblock >> 2;		// Because A18 and A19 are already sent out
	
	*pNFC_ADDR = RIblock;
	
		
	// Block address greater than 1023
	
	RIblock = temp_Block;
	RIblock = RIblock & 0xFC00;		// Mask to get A28-A30
	RIblock = RIblock >> 10;		// Because A18-A27 are already sent out
	
	*pNFC_ADDR = RIblock;
	
	// Wait till write buffer is empty:
	
	while(!(*pNFC_STAT & WB_EMPTY));
		
		
	// Issue Random Data Input command
	*pNFC_CMD = RandomDataInputCmd[0];
				
		
	// Now issue Address cycle to change the Column address
		
	*pNFC_ADDR = RIbyte;		//A0-A7
	*pNFC_ADDR = RIbyte >> 8;	//A8-A11
		
	// Write the Data to be written here.
	// Only one data is written in this example. Once the column address is changed
	// user can write to remaining bytes of a page. Ensure that write buffer is NOT full 
		
	*pNFC_DATA_WR = DataIn;
		
	
	// Wait till write buffer is empty:
	
	while(!(*pNFC_STAT & WB_EMPTY));	
	// Issue confirm code now
		
	*pNFC_CMD = PageWriteCmd[1];
		
		
	//Wait till NBUSY Flag sets.
	
	while(!(NBUSY_Flag));                                                                                         
	NBUSY_Flag = 0;
		
	printf("Random Data Input is completed \n");
		
}


		
		
		
		
		
		
		
		
		

